==> arrow-docs-0.8.0-sources.jar: arrow/optics/Address$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Address`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Address`, arrow.core.Tuple2<`kotlin`.`String`, `arrow`.`optics`.`Street`>> inline get()= arrow.optics.Iso(
  get = { address: `arrow`.`optics`.`Address` -> arrow.core.Tuple2(address.`city`, address.`street`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`String`, `arrow`.`optics`.`Street`> -> `arrow`.`optics`.`Address`(tuple.a, tuple.b) }
)

inline val `arrow`.`optics`.`Address`.Companion.city: arrow.optics.Lens<`arrow`.`optics`.`Address`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { address: `arrow`.`optics`.`Address` -> address.`city` },
  set = { value: `kotlin`.`String` ->
    { address: `arrow`.`optics`.`Address` ->
      address.copy(`city` = value)
    }
  }
)

inline val `arrow`.`optics`.`Address`.Companion.street: arrow.optics.Lens<`arrow`.`optics`.`Address`, `arrow`.`optics`.`Street`> inline get()= arrow.optics.Lens(
  get = { address: `arrow`.`optics`.`Address` -> address.`street` },
  set = { value: `arrow`.`optics`.`Street` ->
    { address: `arrow`.`optics`.`Address` ->
      address.copy(`street` = value)
    }
  }
)




inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Address`>.city: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Address`.city
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Address`>.city: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Address`.city
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Address`>.city: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Address`.city
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Address`>.city: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Address`.city
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Address`>.city: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Address`.city
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Address`>.city: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Address`.city
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Address`>.city: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Address`.city
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Address`>.city: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Address`.city

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Address`>.street: arrow.optics.Lens<S, `arrow`.`optics`.`Street`> inline get() = this + `arrow`.`optics`.`Address`.street
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Address`>.street: arrow.optics.Lens<S, `arrow`.`optics`.`Street`> inline get() = this + `arrow`.`optics`.`Address`.street
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Address`>.street: arrow.optics.Optional<S, `arrow`.`optics`.`Street`> inline get() = this + `arrow`.`optics`.`Address`.street
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Address`>.street: arrow.optics.Optional<S, `arrow`.`optics`.`Street`> inline get() = this + `arrow`.`optics`.`Address`.street
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Address`>.street: arrow.optics.Getter<S, `arrow`.`optics`.`Street`> inline get() = this + `arrow`.`optics`.`Address`.street
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Address`>.street: arrow.optics.Setter<S, `arrow`.`optics`.`Street`> inline get() = this + `arrow`.`optics`.`Address`.street
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Address`>.street: arrow.optics.Traversal<S, `arrow`.`optics`.`Street`> inline get() = this + `arrow`.`optics`.`Address`.street
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Address`>.street: arrow.optics.Fold<S, `arrow`.`optics`.`Street`> inline get() = this + `arrow`.`optics`.`Address`.street

==> arrow-docs-0.10.3-sources.jar: arrow/optics/Address$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Address`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Address`, arrow.core.Tuple2<`kotlin`.`String`, `arrow`.`optics`.`Street`>> inline get()= arrow.optics.Iso(
  get = { address: `arrow`.`optics`.`Address` -> arrow.core.Tuple2(address.`city`, address.`street`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`String`, `arrow`.`optics`.`Street`> -> `arrow`.`optics`.`Address`(tuple.a, tuple.b) }
)

inline val `arrow`.`optics`.`Address`.Companion.city: arrow.optics.Lens<`arrow`.`optics`.`Address`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { address: `arrow`.`optics`.`Address` -> address.`city` },
  set = { address: `arrow`.`optics`.`Address`, value: `kotlin`.`String` -> address.copy(`city` = value) }
)

inline val `arrow`.`optics`.`Address`.Companion.street: arrow.optics.Lens<`arrow`.`optics`.`Address`, `arrow`.`optics`.`Street`> inline get()= arrow.optics.Lens(
  get = { address: `arrow`.`optics`.`Address` -> address.`street` },
  set = { address: `arrow`.`optics`.`Address`, value: `arrow`.`optics`.`Street` -> address.copy(`street` = value) }
)




inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Address`>.city: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Address`.city
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Address`>.city: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Address`.city
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Address`>.city: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Address`.city
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Address`>.city: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Address`.city
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Address`>.city: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Address`.city
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Address`>.city: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Address`.city
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Address`>.city: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Address`.city
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Address`>.city: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Address`.city

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Address`>.street: arrow.optics.Lens<S, `arrow`.`optics`.`Street`> inline get() = this + `arrow`.`optics`.`Address`.street
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Address`>.street: arrow.optics.Lens<S, `arrow`.`optics`.`Street`> inline get() = this + `arrow`.`optics`.`Address`.street
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Address`>.street: arrow.optics.Optional<S, `arrow`.`optics`.`Street`> inline get() = this + `arrow`.`optics`.`Address`.street
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Address`>.street: arrow.optics.Optional<S, `arrow`.`optics`.`Street`> inline get() = this + `arrow`.`optics`.`Address`.street
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Address`>.street: arrow.optics.Getter<S, `arrow`.`optics`.`Street`> inline get() = this + `arrow`.`optics`.`Address`.street
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Address`>.street: arrow.optics.Setter<S, `arrow`.`optics`.`Street`> inline get() = this + `arrow`.`optics`.`Address`.street
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Address`>.street: arrow.optics.Traversal<S, `arrow`.`optics`.`Street`> inline get() = this + `arrow`.`optics`.`Address`.street
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Address`>.street: arrow.optics.Fold<S, `arrow`.`optics`.`Street`> inline get() = this + `arrow`.`optics`.`Address`.street
